============
Installation
============

As in most experiences with python packages, it is advisable to create a virtual environment before installing ``pysll``. This can be done with
your favorite package manager (e.g. ``conda``):

.. code-block:: sh

    $ conda create -n myenv python
    $ conda activate myenv

Once your environment has been activated, installation is very easy with ``pip``:

.. code-block:: python

    pip install pysll

That's it you're done, go checkout the :doc:`getting-started` to start using ``pysll``!
